@@ -1,3 +1,4 @@
+import os
 import logging
 
 logging.basicConfig(level = logging.INFO, format = '%(message)s')
@@ -8,7 +9,11 @@ def setAPI(api_url, api_port):
                 '\n',
                 "BACK_END_API_PORT = '{}'".format(api_port)]
     
-    LcConst_path = '/usr/lib/modeler-python-package/Accuinsight/modeler/core/LcConst/LcConst.py'   # 수정 필요
+    LcConst_path = '/opt/conda/lib/python3.7/site-packages/Accuinsight/modeler/core/LcConst/LcConst.py'
+    if os.path.isfile(LcConst_path) == False:
+            LcConst_path = '/opt/conda/lib/python3.6/site-packages/Accuinsight/modeler/core/LcConst/LcConst.py'
+    else:
+        pass
     
     with open(LcConst_path, 'r+') as f:
         new_f = f.readlines()
