@@ -17,6 +17,9 @@ class RunObject:
     def set_csv_path(self, csv_path):
         self.run_obj[RUN_OBJ_CSV_PATH] = csv_path
 
+    def set_shap_path(self, shap_path):
+        self.run_obj[RuN_OBJ_SHAP_PATH] = shap_path
+
     def set_run_name(self, run_name):
         self.run_obj[RUN_OBJ_NAME] = run_name
 
